class NpbApi::Game
  def initialize(date: '', id: '')
    @date = date
    @id = (date.year.to_s + format('%02d', date.month) + format('%02d', date.day) + id).to_i
    @doc = Nokogiri::HTML(open("http://baseball.yahoo.co.jp/npb/game/#{@id}/top"))
  end

  def away
    info(:away)
  end

  def home
    info(:home)
  end

  private

  def info(home_or_away)
    {
      id: @id,
      status: status,
      team_id: team_id(home_or_away),
      score: score(home_or_away),
      result: result(home_or_away),
      datetime: datetime,
      ballpark: ballpark
    }
  end

  def status
    @doc.css('.column-center em').text
  end

  def score(home_or_away)
    return nil if status == '試合前中止'

    case home_or_away
    when :away then @doc.css('tr#tb1 td.sum').text.to_i
    when :home then @doc.css('tr#tb2 td.sum').text.to_i
    end
  end

  def result(home_or_away)
    return 'postponed' if status.include?('中止')

    case home_or_away
    when :away
      if score(:away) > score(:home)
        'win'
      elsif score(:away) < score(:home)
        'lose'
      else
        'draw'
      end
    when :home
      if score(:home) > score(:away)
        'win'
      elsif score(:home) < score(:away)
        'lose'
      else
        'draw'
      end
    end
  end

  def home_result
    return 'postponed' if status.include?('中止')

  end

  def datetime
    hour, minute = @doc.css('p.stadium').children[2].text.split(':').map(&:to_i)
    DateTime.new(@date.year, @date.month, @date.day, hour, minute, 0, '+9')
  end

  def ballpark
    @doc.css('p.stadium').children[0].text.strip
  end

  def team_id(home_or_away)
    anchor =
      case home_or_away
      when :home then @doc.css('.column-left.clearfix a')
      when :away then @doc.css('.column-right.clearfix a')
      end
    anchor.attribute('href').value =~ /\A\/npb\/teams\/(\d+)\/\z/
    $1.to_i
  end
end
