class NpbApi::Player
  def initialize(id: '')
    @id = id
    @doc = Nokogiri::HTML(open("http://baseball.yahoo.co.jp/npb/player/#{id}/")).css('#profile')
  end

  def info
    {
      id: @id.to_i,
      name: @doc.css('.NpbTeamTop').children.children[0].text,
      kana: kana,
      number: @doc.css('.NpbTeamTop').children.children.children[1].text,
      position: @doc.css('.NpbTeamTop').children.children.children[2].text,
      birthday: birthday,
      age: age,
      birthplace: @doc.css('tr')[0].children.children[-1].text,
      height: height,
      weight: weight,
      blood_type: blood_type,
      throw: _throw,
      bat: bat,
      draft_year: draft_year,
      draft_rank: draft_rank,
      total_years: total_years,
      carrier: @doc.css('tr')[3].children.children[-1].text,
      title: title
    }
  end

  private

  def kana
    @doc.css('.NpbTeamTop').children.children.children[0].text =~ /\A（(.+)）\z/
    $1
  end

  def birthday
    @doc.css('tr')[0].children.children[2].text =~ /\A(\d{4})年(\d{1,2})月(\d{1,2})日（\d{2}歳）\z/
    Date.new($1.to_i, $2.to_i, $3.to_i)
  end

  def age
    @doc.css('tr')[0].children.children[2].text =~ /\A\d{4}年\d{1,2}月\d{1,2}日（(\d{2})歳）\z/
    $1.to_i
  end

  def height
    @doc.css('tr')[1].children.children[1].text =~ /\A(\d{3})cm\/\d{2,3}kg（.+）\z/
    $1.to_i
  end

  def weight
    @doc.css('tr')[1].children.children[1].text =~ /\A\d{3}cm\/(\d{2,3})kg（.+）\z/
    $1.to_i
  end

  def blood_type
    @doc.css('tr')[1].children.children[1].text =~ /\A\d{3}cm\/\d{2,3}kg（(.+)）\z/
    $1
  end

  # NOTE: 予約語と重複するためアンスコをつけている
  def _throw
    @doc.css('tr')[1].children.children[-1].text =~ /\A(.)投げ.打ち\z/
    $1
  end

  def bat
    @doc.css('tr')[1].children.children[-1].text =~ /\A.投げ(.)打ち\z/
    $1
  end

  def draft_year
    if @doc.css('tr')[2].children.children[1].text =~ /\A(\d{4})年（.+）\z/
      $1.to_i
    else
      nil
    end
  end

  def draft_rank
    if @doc.css('tr')[2].children.children[1].text =~ /\A\d{4}年（(.+)）\z/
      $1
    else
      nil
    end
  end

  def total_years
    @doc.css('tr')[2].children.children[-1].text =~ /\A(\d+)年\z/
    $1.to_i
  end

  def title
    if @doc.css('tr')[4].children.children[-1].text == '-'
      nil
    else
      @doc.css('tr')[4].children.children[-1].text
    end
  end
end
